@@ -2,9 +2,9 @@ import sys
 
 
 class PrintCatcher(object):
-    def __init__(self, stream='stdout'):
-        self.text = ''
-        if stream not in {'stdout', 'stderr'}:
+    def __init__(self, stream="stdout"):
+        self.text = ""
+        if stream not in {"stdout", "stderr"}:
             raise ValueError('stream must be either "stdout" or "stderr"')
         self.stream = stream
 
@@ -15,14 +15,14 @@ class PrintCatcher(object):
         pass
 
     def __enter__(self):
-        if self.stream == 'stdout':
+        if self.stream == "stdout":
             sys.stdout = self
         else:
             sys.stderr = self
         return self
 
     def __exit__(self, *args):
-        if self.stream == 'stdout':
+        if self.stream == "stdout":
             sys.stdout = sys.__stdout__
         else:
             sys.stderr = sys.__stderr__
